@@ -20,6 +20,13 @@
 
 #include "includes.h"
 
+
+/* default to using LANMAN1 */
+#ifndef LANMAN1
+#define LANMAN1 1
+#endif
+
+
 pstring cur_dir = "\\";
 pstring cd_path = "";
 pstring service;
@@ -125,7 +132,7 @@ BOOL chkpath(char *path)
   strcpy(p,path);
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
 
   return(CVAL(inbuf,smb_rcls) == 0);
 }
@@ -168,111 +175,6 @@ void cmd_cd(char *inbuf,char *outbuf )
   strcpy(cd_path,cur_dir);
 }
 
-/****************************************************************************
-do a directory listing, calling fn on each file found
-****************************************************************************/
-void do_dir_old(char *inbuf,char *outbuf,char *mask,int attribute,void (*fn)())
-{
-  char *p;
-  int received = 0;
-  BOOL first = True;
-  char status[21];
-  int num_asked = (max_xmit - 500)/DIR_STRUCT_SIZE;
-  int num_received = 0;
-
-  while (1)
-    {
-      memset(outbuf,0,smb_size);
-      if (first)	
-	set_message(outbuf,2,5 + strlen(mask));
-      else
-	set_message(outbuf,2,5 + 21);
-
-      CVAL(outbuf,smb_com) = SMBsearch;
-      SSVAL(outbuf,smb_tid,cnum);
-      setup_pkt(outbuf);
-
-      SSVAL(outbuf,smb_vwv0,num_asked);
-      SSVAL(outbuf,smb_vwv1,attribute);
-  
-      p = smb_buf(outbuf);
-      *p++ = 4;
-      
-      if (first)
-	strcpy(p,mask);
-      else
-	strcpy(p,"");
-      p += strlen(p) + 1;
-      
-      *p++ = 5;
-      if (first)
-	SSVAL(p,0,0);
-      else
-	{
-	  SSVAL(p,0,21);
-	  p += 2;
-	  memcpy(p,status,21);
-	}
-
-      send_smb(outbuf);
-      receive_smb(inbuf);
-      first = False;
-
-#if 0
-      if (CVAL(inbuf,smb_rcls) != 0)
-	break;
-#endif
-      
-      num_received = received = SVAL(inbuf,smb_vwv0);
-      if (received == 0)
-	{
-	  Debug(1,"dir finished %s\n",smb_errstr(inbuf));
-	  break;
-	}
-
-      p = smb_buf(inbuf) + 3;
-
-      while (received--)
-	{
-	  file_info finfo = def_finfo;
-	  uint32 Date;
-	  char attrstr[10]="";
-
-	  memcpy(status,p,21);
-
-	  finfo.mode = CVAL(p,21);
-	  memcpy(&Date,p+22,4);
-	  finfo.mtime = make_unix_date(Date);
-#ifdef EXTENDED
-	  finfo.atime = make_unix_date(Date);
-	  finfo.ctime = make_unix_date(Date);
-#endif
-	  finfo.size = SVAL(p,26) + (SVAL(p,28)<<16);
-	  strcpy(finfo.name,p+30);
-
-	  if (finfo.mode & aDIR) strcat(attrstr,"D");
-	  if (finfo.mode & aARCH) strcat(attrstr,"A");
-	  if (finfo.mode & aHIDDEN) strcat(attrstr,"H");
-	  if (finfo.mode & aSYSTEM) strcat(attrstr,"S");
-	  if (finfo.mode & aRONLY) strcat(attrstr,"R");	  
-
-	  if (!((finfo.mode & aDIR) == 0 && *fileselection && 
-		!mask_match(finfo.name,fileselection,False,False)))
-	    {
-	      if (fn)
-		fn(&finfo);
-	      else
-		Debug(0,"%20.20s%7.7s%7d  %s",
-		      finfo.name,
-		      attrstr,
-		      finfo.size,
-		      asctime(LocalTime(&finfo.mtime)));
-	    }
-	  p += DIR_STRUCT_SIZE;
-	}
-    }
-}
-
 
 /****************************************************************************
 do a directory listing, calling fn on each file found
@@ -322,7 +224,7 @@ void do_dir(char *inbuf,char *outbuf,char *mask,int attribute,void (*fn)())
 	}
 
       send_smb(outbuf);
-      receive_smb(inbuf);
+      receive_smb(inbuf,0);
       first = False;
 
       received = SVAL(inbuf,smb_vwv0);
@@ -378,7 +280,7 @@ void do_dir(char *inbuf,char *outbuf,char *mask,int attribute,void (*fn)())
 	  if (fn)
 	    fn(&finfo);
 	  else
-	    Debug(0,"%20.20s%7.7s%7d  %s",
+	    Debug(0,"%20.20s%7.7s%10d  %s",
 		  finfo.name,
 		  attrstr,
 		  finfo.size,
@@ -427,7 +329,7 @@ void do_get(char *rname,char *lname)
   uint32 nread=0;
   char *p;
   BOOL newhandle = False;
-  unsigned char *inbuf,*outbuf;
+  char *inbuf,*outbuf;
   file_info finfo = def_finfo;
 
 #ifdef STATS
@@ -443,8 +345,8 @@ void do_get(char *rname,char *lname)
     strlower(lname);
 
 
-  inbuf = (unsigned char *)malloc(BUFFER_SIZE);
-  outbuf = (unsigned char *)malloc(BUFFER_SIZE);
+  inbuf = (char *)malloc(BUFFER_SIZE);
+  outbuf = (char *)malloc(BUFFER_SIZE);
 
   if (!inbuf || !outbuf)
     {
@@ -482,7 +384,7 @@ void do_get(char *rname,char *lname)
 	}
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
 
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -520,7 +422,7 @@ void do_get(char *rname,char *lname)
 	  SSVAL(outbuf,smb_vwv0,fnum);
 
 	  send_smb(outbuf);
-	  receive_smb(inbuf);
+	  receive_smb(inbuf,0);
       
 	  if (CVAL(inbuf,smb_rcls) == 0)
 	    {
@@ -541,7 +443,7 @@ void do_get(char *rname,char *lname)
 
   while (nread < finfo.size)
     {
-      unsigned char *dataptr;
+      char *dataptr;
       int datalen;
       
       Debug(3,"nread=%d\n",nread);
@@ -594,7 +496,7 @@ void do_get(char *rname,char *lname)
 	  SSVAL(outbuf,smb_vwv4,finfo.size - nread);
 
 	  send_smb(outbuf);
-	  receive_smb(inbuf);
+	  receive_smb(inbuf,0);
 
 	  if (CVAL(inbuf,smb_rcls) != 0)
 	    {
@@ -631,7 +533,7 @@ void do_get(char *rname,char *lname)
   SIVAL(outbuf,smb_vwv1,finfo.mtime);
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
   
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -661,14 +563,16 @@ get a file from rname to lname
 ****************************************************************************/
 void do_small_get(char *Rname,char *Lname,file_info *finfo)
 {
+#define CHAIN_CLOSE 0
   int handle;
   char *p;
   BOOL newhandle = False;
-  unsigned char *inbuf,*outbuf;
+  char *inbuf,*outbuf;
   pstring rname,lname;
-  char *outbuf2,*outbuf3;
-
-#define CHAIN_CLOSE 0
+  char *outbuf2;
+#if CHAIN_CLOSE
+  char *outbuf3;
+#endif
 
 #ifdef STATS
   struct timeval tp_start,tp_end;
@@ -685,8 +589,8 @@ void do_small_get(char *Rname,char *Lname,file_info *finfo)
     strlower(lname);
 
 
-  inbuf = (unsigned char *)malloc(BUFFER_SIZE);
-  outbuf = (unsigned char *)malloc(BUFFER_SIZE);
+  inbuf = (char *)malloc(BUFFER_SIZE);
+  outbuf = (char *)malloc(BUFFER_SIZE);
 
   if (!inbuf || !outbuf)
     {
@@ -747,7 +651,7 @@ void do_small_get(char *Rname,char *Lname,file_info *finfo)
 #endif
 #endif
       send_smb(outbuf);
-      receive_smb(inbuf);
+      receive_smb(inbuf,0);
       
       if (CVAL(inbuf,smb_rcls) != 0)
 	{
@@ -805,7 +709,7 @@ void do_small_get(char *Rname,char *Lname,file_info *finfo)
       SSVAL(outbuf,smb_vwv2,0);
       
       send_smb(outbuf);
-      receive_smb(inbuf);
+      receive_smb(inbuf,0);
       
       if (CVAL(inbuf,smb_rcls) != 0)
 	{
@@ -892,10 +796,10 @@ void do_mget(file_info *finfo)
     {
       pstring saved_curdir;
       pstring mget_mask;
-      unsigned char *inbuf,*outbuf;
+      char *inbuf,*outbuf;
 
-      inbuf = (unsigned char *)malloc(BUFFER_SIZE);
-      outbuf = (unsigned char *)malloc(BUFFER_SIZE);
+      inbuf = (char *)malloc(BUFFER_SIZE);
+      outbuf = (char *)malloc(BUFFER_SIZE);
 
       if (!inbuf || !outbuf)
 	{
@@ -988,10 +892,10 @@ make a directory of name "name"
 BOOL do_mkdir(char *name)
 {
   char *p;
-  unsigned char *inbuf,*outbuf;
+  char *inbuf,*outbuf;
 
-  inbuf = (unsigned char *)malloc(BUFFER_SIZE);
-  outbuf = (unsigned char *)malloc(BUFFER_SIZE);
+  inbuf = (char *)malloc(BUFFER_SIZE);
+  outbuf = (char *)malloc(BUFFER_SIZE);
 
   if (!inbuf || !outbuf)
     {
@@ -1012,7 +916,7 @@ BOOL do_mkdir(char *name)
   strcpy(p,name);
   
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
   
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -1033,15 +937,15 @@ set the attributes and date of a file
 BOOL do_setattr(file_info *finfo)
 {
   char *p;
-  unsigned char *inbuf,*outbuf;
+  char *inbuf,*outbuf;
   pstring name;
 
   strcpy(name,finfo->name);
   strcpy(finfo->name,"\\");
   strcat(finfo->name,name);
 
-  inbuf = (unsigned char *)malloc(BUFFER_SIZE);
-  outbuf = (unsigned char *)malloc(BUFFER_SIZE);
+  inbuf = (char *)malloc(BUFFER_SIZE);
+  outbuf = (char *)malloc(BUFFER_SIZE);
 
   if (!inbuf || !outbuf)
     {
@@ -1067,7 +971,7 @@ BOOL do_setattr(file_info *finfo)
   *p++ = 0;
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
   
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -1132,10 +1036,10 @@ void do_put(char *rname,char *lname,file_info *finfo)
   FILE *f;
   int nread=0;
   char *p;
-  unsigned char *inbuf,*outbuf;
+  char *inbuf,*outbuf;
 
-  inbuf = (unsigned char *)malloc(BUFFER_SIZE);
-  outbuf = (unsigned char *)malloc(BUFFER_SIZE);
+  inbuf = (char *)malloc(BUFFER_SIZE);
+  outbuf = (char *)malloc(BUFFER_SIZE);
 
   if (!inbuf || !outbuf)
     {
@@ -1159,7 +1063,7 @@ void do_put(char *rname,char *lname,file_info *finfo)
   strcpy(p,rname);
   
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
   
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -1209,7 +1113,7 @@ void do_put(char *rname,char *lname,file_info *finfo)
 	}	  
 
       send_smb(outbuf);
-      receive_smb(inbuf);
+      receive_smb(inbuf,0);
 
       if (CVAL(inbuf,smb_rcls) != 0)
 	{
@@ -1249,7 +1153,7 @@ void do_put(char *rname,char *lname,file_info *finfo)
   }
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
 
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -1267,7 +1171,7 @@ void do_put(char *rname,char *lname,file_info *finfo)
   SIVAL(outbuf,smb_vwv1,finfo->mtime);
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
   
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -1483,7 +1387,7 @@ void cmd_print(char *inbuf,char *outbuf )
   strcpy(p,rname);
   
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
   
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -1544,7 +1448,7 @@ void cmd_print(char *inbuf,char *outbuf )
       SSVAL(smb_buf(outbuf),1,n);
 
       send_smb(outbuf);
-      receive_smb(inbuf);
+      receive_smb(inbuf,0);
 
       if (CVAL(inbuf,smb_rcls) != 0)
 	{
@@ -1566,7 +1470,7 @@ void cmd_print(char *inbuf,char *outbuf )
   SSVAL(outbuf,smb_vwv0,fnum);
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
   
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -1587,7 +1491,7 @@ delete some files
 void do_del(file_info *finfo)
 {
   char *p;
-  unsigned char *inbuf,*outbuf;
+  char *inbuf,*outbuf;
   pstring mask;
 
   strcpy(mask,cur_dir);
@@ -1596,8 +1500,8 @@ void do_del(file_info *finfo)
   if (finfo->mode & aDIR) 
     return;
 
-  inbuf = (unsigned char *)malloc(BUFFER_SIZE);
-  outbuf = (unsigned char *)malloc(BUFFER_SIZE);
+  inbuf = (char *)malloc(BUFFER_SIZE);
+  outbuf = (char *)malloc(BUFFER_SIZE);
   
   if (!inbuf || !outbuf)
     {
@@ -1619,7 +1523,7 @@ void do_del(file_info *finfo)
   strcpy(p,mask);
   
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
   
   if (CVAL(inbuf,smb_rcls) != 0)
     Debug(0,"%s deleting remote file %s\n",smb_errstr(inbuf),mask);
@@ -1688,7 +1592,7 @@ void cmd_rmdir(char *inbuf,char *outbuf )
   strcpy(p,mask);
   
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
   
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -1795,7 +1699,7 @@ BOOL send_login(char *inbuf,char *outbuf )
     {
       {PROT_CORE,"PC NETWORK PROGRAM 1.0"},
       {PROT_COREPLUS,"MICROSOFT NETWORKS 1.03"},
-#ifdef LANMAN1
+#if LANMAN1
       {PROT_LANMAN1,"MICROSOFT NETWORKS 3.0"},
       {PROT_LANMAN1,"LANMAN1.0"},
 #if 0
@@ -1837,11 +1741,12 @@ BOOL send_login(char *inbuf,char *outbuf )
     CVAL(outbuf,1) |= 1;
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
  
   if (CVAL(inbuf,0) != 0x82)
     {
-      Debug(0,"Session request failed (%d)\n",CVAL(inbuf,0));
+      Debug(0,"Session request failed (%d) with myname=%s destname=%s\n",
+	    CVAL(inbuf,0),myname,desthost);
       return(False);
     }      
 
@@ -1872,15 +1777,16 @@ BOOL send_login(char *inbuf,char *outbuf )
   CVAL(smb_buf(outbuf),0) = 2;
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
 
-  if (CVAL(inbuf,smb_rcls) != 0 || (SVAL(inbuf,smb_vwv0) >= numprots))
+  if (CVAL(inbuf,smb_rcls) != 0 || ((int)SVAL(inbuf,smb_vwv0) >= numprots))
     {
-      Debug(0,"SMBnegprot failed. %s\n", smb_errstr(inbuf));
+      Debug(0,"SMBnegprot failed. myname=%s destname=%s - %s \n",
+	    myname,desthost,smb_errstr(inbuf));
       return(False);
     }
 
-  max_xmit = MIN(max_xmit,SVAL(inbuf,smb_vwv2));
+  max_xmit = MIN(max_xmit,(int)SVAL(inbuf,smb_vwv2));
 
   Debug(3,"Sec mode %d\n",SVAL(inbuf,smb_vwv1));
   Debug(3,"max xmt %d\n",SVAL(inbuf,smb_vwv2));
@@ -1928,11 +1834,12 @@ BOOL send_login(char *inbuf,char *outbuf )
       strcpy(p,username);
 
       send_smb(outbuf);
-      receive_smb(inbuf);      
+      receive_smb(inbuf,0);      
 
       if (CVAL(inbuf,smb_rcls) != 0)
 	{
-	  Debug(0,"Session setup failed: %s\n",smb_errstr(inbuf));
+	  Debug(0,"Session setup failed for username=%s myname=%s destname=%s   %s\n",
+		username,myname,desthost,smb_errstr(inbuf));
 	  return(False);
 	}
     }
@@ -1959,7 +1866,7 @@ BOOL send_login(char *inbuf,char *outbuf )
   strcpy(p,dev);
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
 
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -1998,7 +1905,7 @@ void send_logout(char *inbuf,char *outbuf )
   setup_pkt(outbuf);
 
   send_smb(outbuf);
-  receive_smb(inbuf);
+  receive_smb(inbuf,0);
 
   if (CVAL(inbuf,smb_rcls) != 0)
     {
@@ -2089,7 +1996,10 @@ BOOL open_sockets(int port )
   host = strtok(service2,"\\/");
   strcpy(desthost,host);
   if (*myname == 0)
-    gethostname(myname,sizeof(myname));
+    {
+      gethostname(myname,sizeof(myname));
+      strupper(myname);
+    }
 
   if (!have_ip)
     {
@@ -2128,7 +2038,7 @@ BOOL open_sockets(int port )
 
   {
     int one=1;
-    setsockopt(Client,SOL_SOCKET,SO_KEEPALIVE,&one,sizeof(one));
+    setsockopt(Client,SOL_SOCKET,SO_KEEPALIVE,(char *)&one,sizeof(one));
   }
 
   return True;
@@ -2154,7 +2064,7 @@ void wait_keyboard(char *buffer)
 	{
 	  timeout.tv_sec = 20;
 	  timeout.tv_usec = 0;
-	  selrtn = select(255,&fds,NULL,NULL,&timeout);
+	  selrtn = select(255,SELECT_CAST &fds,NULL,NULL,&timeout);
 	}
       while(selrtn < 0 && errno == EINTR);
 
@@ -2162,7 +2072,7 @@ void wait_keyboard(char *buffer)
 	return;
 
       if (FD_ISSET(Client,&fds))
-	receive_smb(buffer);
+	receive_smb(buffer,0);
 
       chkpath("\\");
     }
@@ -2265,7 +2175,16 @@ int main(int argc,char *argv[])
   umask(myumask);
 
   if (getenv("USER"))
-    strcpy(username,getenv("USER"));
+    {
+      strcpy(username,getenv("USER"));
+      strupper(username);
+    }
+
+  if (*username == 0 && getenv("LOGNAME"))
+    {
+      strcpy(username,getenv("LOGNAME"));
+      strupper(username);
+    }
 
   if (argc < 2)
     {
