@@ -17,7 +17,11 @@
 #include <sys/param.h>
 #include <sys/mount.h>
 #include <pwd.h>
+#ifdef __STDC__
+#include <stdarg.h>
+#else
 #include <varargs.h>
+#endif
 #include <unistd.h>
 #include <sys/wait.h>
 #include <net/if.h>
@@ -56,7 +60,6 @@ struct utimbuf {
   time_t modtime;
 };
 typedef unsigned short mode_t;
-void abort();
 #endif
 #ifndef strerror
 extern char *sys_errlist[];
@@ -75,6 +78,7 @@ extern char *sys_errlist[];
 #define HAVE_TIMEZONE
 #define SIGNAL_CAST (void (*)(int))
 #define SYSV
+#define REPLACE_STRLEN
 #endif
 
 #ifdef SVR4
@@ -137,6 +141,7 @@ struct spwd *getspnam(char *username); /* fake shadow password routine */
 #include <dirent.h>
 #include <sys/statfs.h>
 #include <sys/vfs.h>
+#define HAVE_TIMEZONE
 #endif
 
 #ifdef HPUX
@@ -147,6 +152,7 @@ struct spwd *getspnam(char *username); /* fake shadow password routine */
 #include <sys/types.h>
 #define SIGNAL_CAST (void (*)(__harg))
 #define SELECT_CAST (int *)
+#define HAVE_TIMEZONE
 #endif
 
 #ifdef SEQUENT
@@ -156,6 +162,17 @@ typedef int mode_t;
 #define SEEK_SET 0
 #endif
 
+#ifdef NEXT
+#include <strings.h>
+#include <sys/dir.h>
+#include <dirent.h>
+#include <sys/vfs.h>
+#define bzero(b,len) memset(b,0,len)
+#include <libc.h>
+#define NOSTRDUP
+#endif
+
+
 #ifdef USE_DIRECT
 #include <sys/dir.h>
 #endif
@@ -163,3 +180,6 @@ typedef int mode_t;
 #include "version.h"
 #include "smb.h"
 
+#ifdef REPLACE_STRLEN
+#define strlen(s) Strlen(s)
+#endif
