@@ -126,6 +126,7 @@ typedef enum
    E_ROOTDIR,
    E_MAXXMIT,
    E_KEEPALIVE,
+   E_DEADTIME,
    E_DONTDESCEND,
    E_HOSTSALLOW,
    E_HOSTSDENY,
@@ -145,6 +146,7 @@ typedef struct
    char *szHostsdeny;
    int max_xmit;
    int keepalive;
+   int deadtime;
    int iCreate_mode;
 } global;
 
@@ -292,6 +294,8 @@ static parmmap aParmMaps[] =
    {"max xmit",      E_MAXXMIT,      E_GLOBAL  },
    {"keepalive",     E_KEEPALIVE,    E_GLOBAL  },
    {"keep alive",    E_KEEPALIVE,    E_GLOBAL  },
+   {"deadtime",      E_DEADTIME,     E_GLOBAL  },
+   {"dead time",     E_DEADTIME,     E_GLOBAL  },
    {"dont descend",  E_DONTDESCEND,  E_SERVICE  },
 };
 
@@ -430,6 +434,7 @@ static void init_globals(void)
    string_init(&Globals.szHostsdeny, "");
    Globals.max_xmit = BUFFER_SIZE;
    Globals.keepalive = 0;
+   Globals.deadtime = 0;
    Globals.iCreate_mode = DEF_CREATE_MASK;
 }
 
@@ -789,6 +794,10 @@ static BOOL do_global_parameter(parmmap *pparmmap, char *pszParmValue)
          Globals.keepalive = atoi(pszParmValue);
          break;
 
+       case E_DEADTIME:
+         Globals.deadtime = atoi(pszParmValue);
+         break;
+
       default:
          Debug(0, "Unsupported global parameter.\n");
          bRetval = False;
@@ -1096,6 +1105,7 @@ static void dump_globals(void)
       printf("\tHosts denied : %s\n",  Globals.szHostsdeny);
       printf("\tMax Xmit     : %d\n",  Globals.max_xmit);
       printf("\tKeepalive    : %d\n",  Globals.keepalive);
+      printf("\tDeadtime     : %d\n",  Globals.deadtime);
       printf("\tCreate mode  : %o\n",  Globals.iCreate_mode);
 }
 
@@ -1207,6 +1217,14 @@ int lp_keepalive(void)
    return (Globals.keepalive);
 }
 
+/***************************************************************************
+Return the deadtime time
+***************************************************************************/
+int lp_deadtime(void)
+{
+   return (Globals.deadtime);
+}
+
 /***************************************************************************
 Return a pointer to the service name of a specified service. It would be 
 MOST unwise to treat the pointer as anything but read-only!
