@@ -501,7 +501,7 @@ BOOL open_sockets(BOOL daemon,int port)
 	}
   
       /* now we've got a socket - we need to bind it */
-      while (bind(Client, (struct sockaddr * ) &sock,sizeof(sock)) < 0) 
+      if (bind(Client, (struct sockaddr * ) &sock,sizeof(sock)) < 0) 
 	{
 	  perror("bind");
 	  close(Client);
@@ -514,7 +514,7 @@ BOOL open_sockets(BOOL daemon,int port)
     }
   /* We will abort gracefully when the client or remote system 
      goes away */
-  signal(SIGPIPE, SIGNAL_CAST abort);
+  signal(SIGPIPE, SIGNAL_CAST Abort);
   return True;
 }
 
