@@ -22,9 +22,16 @@
 #include "loadparm.h"
 #include "pcap.h"
 
+/* default to not LANMAN1 */
+#ifndef LANMAN1
+#define LANMAN1 0
+#endif
+
 pstring servicesf = SERVICES;
 pstring debugf = DEBUGFILE;
 
+BOOL append_log = True;
+
 char *InBuffer = NULL;
 char *OutBuffer = NULL;
 
@@ -48,6 +55,9 @@ int chain_size = 0;
 /* a fnum to use when chaining */
 int chain_fnum = -1;
 
+/* total number of open files */
+int num_files_open = 0;
+
 /****************************************************************************
   change a dos mode to a unix mode
 ****************************************************************************/
@@ -359,6 +369,10 @@ BOOL get_dir_entry(int cnum,char *mask,int dirtype,char *fname,int *size,int *mo
       if (mask_match(dptr->d_name,mask,!isrootdir,True))
 	{
 	  strcpy(fname,dptr->d_name);
+#if 0
+	  /* possibly convert the name to a msdos name */
+	  hash_name(fname);
+#endif
 	  strcpy(path,Connections[cnum].dirpath);
 	  strcat(path,"/");
 	  strcat(path,fname);
@@ -466,16 +480,6 @@ BOOL unbecome_user(void )
   return(True);
 }
 
-/****************************************************************************
-  Signal handler for SIGPIPE (write on a disconnected socket) 
-****************************************************************************/
-void abort(void )
-{
-  Debug(0,"Abort called. Probably got SIGPIPE\n");
-  exit(1);
-}
-
-
 /****************************************************************************
   find a service entry
 ****************************************************************************/
@@ -711,7 +715,7 @@ this prevents zombie child processes
 ****************************************************************************/
 int sig_cld()
 {
-#ifdef SYSV
+#if (defined(SYSV) || defined(NEXT))
   while (waitpid((pid_t)-1,(int *)NULL, WNOHANG) > 0);
 #else /* BSD */
 #endif
@@ -726,7 +730,7 @@ int sig_cld()
   signal(SIGCLD, SIGNAL_CAST sig_cld);
 
 
-#ifndef SYSV
+#if (!(defined(SYSV) || defined(NEXT)))
 #ifdef HPUX
   while (wait3((int *)NULL, WNOHANG, (int *)NULL) > 0);
 #else
@@ -830,13 +834,13 @@ BOOL open_sockets(BOOL daemon,int port)
 #else
 	  if (Client != -1 && fork()==0)
 	    {
-	      signal(SIGPIPE, SIGNAL_CAST abort);
+	      signal(SIGPIPE, SIGNAL_CAST Abort);
 	      signal(SIGCLD, SIGNAL_CAST SIG_DFL);
 
 	      /* now set appropriate socket options */
 	      {
 		int one=1;
-		setsockopt(Client,SOL_SOCKET,SO_KEEPALIVE,&one,sizeof(one));
+		setsockopt(Client,SOL_SOCKET,SO_KEEPALIVE,(char *)&one,sizeof(one));
 	      }
 	      return True; 
 	    }
@@ -850,14 +854,14 @@ BOOL open_sockets(BOOL daemon,int port)
     {
       /* We will abort gracefully when the client or remote system 
 	 goes away */
-      signal(SIGPIPE, SIGNAL_CAST abort);
+      signal(SIGPIPE, SIGNAL_CAST Abort);
       Client = 0;
     }
 
   /* now set appropriate socket options */
   {
     int one=1;
-    setsockopt(Client,SOL_SOCKET,SO_KEEPALIVE,&one,sizeof(one));
+    setsockopt(Client,SOL_SOCKET,SO_KEEPALIVE,(char *)&one,sizeof(one));
   }
 
   return True;
@@ -968,7 +972,7 @@ struct {
   char *proto_name;
   int (*proto_reply_fn)(char *, int);
 } supported_protocols[] = {
-#ifdef LANMAN1
+#if LANMAN1
   {"LANMAN1.0", reply_lanman1 },
   {"MICROSOFT NETWORKS 3.0", reply_lanman1 },
 #endif
@@ -1676,6 +1680,7 @@ int reply_open(char *inbuf,char *outbuf,int length,int bufsize)
 		}	      
 	      if (ok)
 		{
+		  num_files_open++;
 		  Files[fnum].open = True;
 		  Files[fnum].can_lock = (openmode != O_RDONLY);
 		  Files[fnum].read_only = (openmode == O_RDONLY);
@@ -1700,7 +1705,7 @@ int reply_open(char *inbuf,char *outbuf,int length,int bufsize)
   SSVAL(outbuf,smb_vwv6,rmode);
   
   
-  Debug(2,"%s open %s fd=%d fnum=%d cnum=%d mode=%d omode=%d\n",timestring(),fname,Files[fnum].fd,fnum,cnum,mode,openmode);
+  Debug(2,"%s open %s fd=%d fnum=%d cnum=%d mode=%d omode=%d (numopen=%d)\n",timestring(),fname,Files[fnum].fd,fnum,cnum,mode,openmode,num_files_open);
   
   return(outsize);
 }
@@ -1816,6 +1821,7 @@ int reply_open_and_X(char *inbuf,char *outbuf,int length,int bufsize)
 		}	 
 	      if (ok)
 		{
+		  num_files_open++;
 		  Files[fnum].open = True;
 		  Files[fnum].can_lock = (openmode != O_RDONLY);
 		  Files[fnum].read_only = (openmode == O_RDONLY);
@@ -1848,7 +1854,9 @@ int reply_open_and_X(char *inbuf,char *outbuf,int length,int bufsize)
   if (file_existed && (openmode & O_TRUNC))
     SSVAL(outbuf,smb_vwv11,3);
 
-  Debug(2,"%s openX %s fd=%d fnum=%d cnum=%d mode=%d omode=%d\n",timestring(),fname,Files[fnum].fd,fnum,cnum,smb_mode,openmode);
+  Debug(2,"%s openX %s fd=%d fnum=%d cnum=%d mode=%d omode=%d (numopen=%d)\n",
+	timestring(),fname,Files[fnum].fd,fnum,cnum,
+	smb_mode,openmode,num_files_open);
 
   chain_fnum = fnum;
 
@@ -1913,9 +1921,10 @@ int reply_create(char *inbuf,char *outbuf,int length,int bufsize)
 	  Files[fnum].fd = open(fname,O_RDWR | O_CREAT | O_TRUNC,unixmode);
 	  if (Files[fnum].fd >= 0)
 	    {
+	      num_files_open++;
+	      Files[fnum].open = True;
 	      Files[fnum].can_lock = True;
 	      Files[fnum].read_only = False;
-	      Files[fnum].open = True;
 	      Files[fnum].cnum = cnum;
 	      strcpy(Files[fnum].name,fname);
 	    }
@@ -1978,6 +1987,7 @@ int reply_ctemp(char *inbuf,char *outbuf,int length,int bufsize)
 	  Files[fnum].fd = creat(fname2,unixmode);
 	  if (Files[fnum].fd >= 0)
 	    {
+	      num_files_open++;
 	      Files[fnum].open = True;
 	      Files[fnum].cnum = cnum;
 	      strcpy(Files[fnum].name,fname2);
@@ -2645,8 +2655,6 @@ int reply_close(char *inbuf,char *outbuf,int length,int bufsize)
       Debug(3,"open jnk\n");
   }
 
-  Debug(3,"close wct = %d inbuf=%d\n",CVAL(inbuf,smb_vwv0-1),(int)inbuf);
-  
   cnum = SVAL(inbuf,smb_tid);
   if (!OPEN_CNUM(cnum))
     return(ERROR(ERRSRV,ERRinvnid));
@@ -2667,6 +2675,7 @@ int reply_close(char *inbuf,char *outbuf,int length,int bufsize)
 	  if (!Files[fnum].read_only)
 	    set_filetime(Files[fnum].name,mtime);
 
+	  num_files_open--;
 	  Files[fnum].open = False;
 	  ok = True;
 	}
@@ -2677,7 +2686,8 @@ int reply_close(char *inbuf,char *outbuf,int length,int bufsize)
     return(ERROR(ERRDOS,eACCESS_DENIED));
   
 
-  Debug(2,"%s close fd=%d fnum=%d cnum=%d ret=%d\n",timestring(),Files[fnum].fd,fnum,cnum,ret);
+  Debug(2,"%s close fd=%d fnum=%d cnum=%d ret=%d (numopen=%d)\n",
+	timestring(),Files[fnum].fd,fnum,cnum,ret,num_files_open);
   
   return(outsize);
 }
@@ -2720,13 +2730,14 @@ int reply_writeclose(char *inbuf,char *outbuf,int length,int bufsize)
 	      ok = True;
 	    }
 	  close(Files[fnum].fd);
+	  num_files_open--;
 	  Files[fnum].open = False;
 	}
       unbecome_user();
     }
   
-  Debug(2,"%s writeclose fnum=%d cnum=%d num=%d wrote=%d\n",
-	timestring(),fnum,cnum,numtowrite,nwritten);
+  Debug(2,"%s writeclose fnum=%d cnum=%d num=%d wrote=%d (numopen=%d)\n",
+	timestring(),fnum,cnum,numtowrite,nwritten,num_files_open);
   
   if ((nwritten <= 0) || !ok)
     return(ERROR(ERRDOS,eACCESS_DENIED));
@@ -2829,6 +2840,7 @@ void close_open_files(int cnum)
   for (i=0;i<MAX_OPEN_FILES;i++)
     if( Files[i].cnum == cnum && Files[i].open == True) {
       close(Files[i].fd);
+      num_files_open--;
       Files[i].open = False;
       Files[i].cnum = -1;
     }
@@ -2845,11 +2857,11 @@ void close_cnum(int cnum)
 
   if (!OPEN_CNUM(cnum))
     {
-      Debug("Can't close cnum %d\n",cnum);
+      Debug(0,"Can't close cnum %d\n",cnum);
       return;
     }
 
-  Debug(1,"%s(%s) has closed a connection to service %s\n",
+  Debug(1,"%s (%s) has closed a connection to service %s\n",
 	Client_info.name,Client_info.addr,lp_servicename(SNUM(cnum)));
 
   close_open_files(cnum);
@@ -2918,6 +2930,7 @@ int reply_printopen(char *inbuf,char *outbuf,int length,int bufsize)
 	  if (Files[fnum].fd >= 0)
 	    {
 	      strcpy(Files[fnum].name,fname2);
+	      num_files_open++;
 	      Files[fnum].open = True;
 	      Files[fnum].cnum = cnum;
 	    }
@@ -3057,6 +3070,7 @@ int reply_printclose(char *inbuf,char *outbuf,int length,int bufsize)
 	      Debug(2,"Running the command `%s' gave %d\n",syscmd,ret);
 	    }
   	}
+      num_files_open--;
       Files[fnum].open = False;
       ok = True;
       unbecome_user();
@@ -3579,6 +3593,7 @@ void process(void )
   extern int Client;
   static int trans_num = 0;
   int nread;
+  int deadtime = lp_deadtime()*60*1000*1000; /* the deadtime is in seconds */
   
   InBuffer = (char *)malloc(BUFFER_SIZE);
   OutBuffer = (char *)malloc(BUFFER_SIZE);
@@ -3592,7 +3607,7 @@ void process(void )
       int msg_flags;
       int type;
 
-      if (!receive_smb(InBuffer))	
+      if (!receive_smb(InBuffer,(num_files_open == 0?deadtime:0)))	
 	return;
       
       msg_type = CVAL(InBuffer,0);
@@ -3655,6 +3670,8 @@ void init_structs(void )
   for (i=0;i<MAX_OPEN_FILES;i++)
     Files[i].open = False;
 
+  num_files_open=0;
+
   init_dptrs();
 }
 
@@ -3704,6 +3721,9 @@ int main(int argc,char *argv[])
       case 'l':
 	strcpy(debugf,optarg);
 	break;
+      case 'a':
+	append_log = !append_log;
+	break;
       case 'D':
 	daemon = True;
 	break;
@@ -3739,7 +3759,10 @@ int main(int argc,char *argv[])
     {
       pstring fname="";
       sprintf(fname,"%s.debug",debugf);      
-      dbf = fopen(fname,"w");
+      if (append_log)
+	dbf = fopen(fname,"a");
+      else
+	dbf = fopen(fname,"w");
       setbuf(dbf,NULL);
       Debug(1,"%s smbserver version %s started\n",timestring(),VERSION);
       Debug(1,"Copyright Andrew Tridgell 1992,1993,1994\n");
