@@ -325,6 +325,7 @@ struct from_host {
 
 
 /* and a few prototypes */
+void Abort(void);
 void *Realloc(void *p,int size);
 void send_logout(char *inbuf,char *outbuf );
 void smb_setlen(char *buf,int len);
@@ -350,7 +351,7 @@ int write_with_timeout(int fd, char *buf, int length, long time_out);
 BOOL send_smb(char *buffer);
 BOOL read_data(int fd,char *buffer,int N);
 int smb_len(char *buf);
-int receive_smb(char *buffer);
+int receive_smb(char *buffer,int timeout);
 void show_msg(char *buf);
 BOOL big_endian(void );
 void become_daemon(void);
@@ -372,7 +373,7 @@ int name_len(char *s);
 void clean_name(char *s);
 time_t make_unix_date(uint32 dos_date);
 void trim_string(char *s,char *front,char *back);
-int byte_checksum(unsigned char *buf,int len);
+int byte_checksum(char *buf,int len);
 void sival(char *buf,int pos,uint32 val);
 BOOL yesno(char *p);
 uint32 file_size(char *file_name);
@@ -388,7 +389,11 @@ void name_extract(char *buf,int ofs,char *name);
 BOOL name_query(char *inbuf,char *outbuf,char *name,struct in_addr *ip);
 BOOL get_broadcast(struct in_addr *if_ipaddr, struct in_addr *if_bcast, struct in_addr *if_nmask);
 BOOL allow_access(char *deny_list,char *allow_list,struct from_host *client);
+#ifdef __STDC__
+void Debug(int, char *, ...);
+#else
 void Debug();
+#endif
 BOOL password_ok(char *user,char *password);
 int chain_reply(int type,char *inbuf,char *inbuf2,char *outbuf,char *outbuf2,int size,int bufsize);
 void close_cnum(int cnum);
@@ -403,7 +408,9 @@ BOOL set_filetime(char *fname,time_t mtime);
 #ifdef NOSTRDUP
 char *strdup(char *s);
 #endif
-
+#ifdef REPLACE_STRLEN
+int Strlen(char *);
+#endif
 
 #ifdef SUN
 struct DIRECT *readdir();
