@@ -54,25 +54,36 @@ BOOL NeedSwap=False;
 /*******************************************************************
 write an debug message on the debugfile. The first arg is the debuglevel.
 ********************************************************************/
+#ifdef __STDC__
+void Debug(int debug_level, char *format_str, ...)
+{
+#else
 void Debug(va_alist)
 va_dcl
 {
-va_list ap;
-char *format_str;
-int debug_level;
+  int debug_level;
+  char *format_str;
+#endif
 
-if (!dbf) return;
+  va_list ap;
+  
+  if (!dbf) return;
+  
+#ifdef __STDC__
+  va_start(ap, level);
+#else
+  va_start(ap);
+  debug_level = va_arg(ap,int);
+  format_str = va_arg(ap,char *);
+#endif
 
-va_start(ap);
-debug_level = va_arg(ap,int);
-format_str = va_arg(ap,char *);
 
-if (DEBUGLEVEL >= debug_level)
-  {
-    vfprintf(dbf,format_str,ap);
-    fflush(dbf);
-  }
-va_end(ap);
+  if (DEBUGLEVEL >= debug_level)
+    {
+      vfprintf(dbf,format_str,ap);
+      fflush(dbf);
+    }
+  va_end(ap);
 }
 
 
@@ -256,7 +267,7 @@ char *timestring(void )
   static char TimeBuf[100];
   time_t t;
   t = time(NULL);
-#ifdef sun386
+#if (defined(sun386) || defined(NEXT))
   strcpy(TimeBuf, asctime(LocalTime(&t)));
 #else
   strftime(TimeBuf,100,"%D %r",LocalTime(&t));
@@ -780,7 +791,7 @@ return the absolute current directory path
 ********************************************************************/
 char *GetWd(char *s)
 {
-#if (defined(LINUX) || defined(SOLARIS) || defined(SVR4) || defined(HPUX))
+#if (defined(LINUX) || defined(SOLARIS) || defined(SVR4) || defined(HPUX) || defined(NEXT))
   return((char *)getcwd(s,sizeof(pstring)));
 #else
   return((char *)getwd(s));
@@ -855,6 +866,7 @@ BOOL reduce_name(char *s,char *dir)
 
   if (chdir(basename) != 0)
     {
+      chdir(wd);
       Debug(3,"couldn't chdir for %s %s basename=%s\n",s,dir,basename);
       return(False);
     }
@@ -879,6 +891,7 @@ BOOL reduce_name(char *s,char *dir)
 
     if (strncmp(newname,dir2,l) != 0)
       {
+	chdir(wd);
 	Debug(2,"Bad access attempt? s=%s dir=%s newname=%s l=%d\n",s,dir2,newname,l);
 	return(False);
       }
@@ -1197,7 +1210,7 @@ int read_with_timeout(int fd,char *buf,int mincnt,int maxcnt, long time_out)
     time_out = DEFAULT_PIPE_TIMEOUT;
 
   /* Blocking read */
-  if(time_out == -1) {
+  if(time_out < 0) {
     return read(fd, buf, maxcnt);
   }
   
@@ -1236,7 +1249,7 @@ int read_with_timeout(int fd,char *buf,int mincnt,int maxcnt, long time_out)
     FD_SET(fd,&fds);
 
     do {    
-      selrtn = select(255,&fds,NULL,NULL,&timeout);
+      selrtn = select(255,SELECT_CAST &fds,NULL,NULL,&timeout);
     } 
     while( selrtn < 0  &&  errno == EINTR );
 
@@ -1374,7 +1387,7 @@ int write_with_timeout(int fd, char *buf, int length, long time_out)
 
     /* Wait with timeout until we can write */
     do {    
-      selrtn = select(255,NULL,&fds,NULL,&timeout);
+      selrtn = select(255,NULL,SELECT_CAST &fds,NULL,&timeout);
     } 
     while( selrtn < 0  &&  errno == EINTR );
 
@@ -1440,7 +1453,7 @@ BOOL send_keepalive(void)
 }
 
 /****************************************************************************
-  read data from the client, reading exactly N bytes. timeout in seconds.
+  read data from the client, reading exactly N bytes. 
 ****************************************************************************/
 BOOL read_data(int fd,char *buffer,int N)
 {
@@ -1488,17 +1501,26 @@ BOOL read_data(int fd,char *buffer,int N)
 
 /****************************************************************************
   read an smb from a fd and return it's length
+The timeout is in micro seconds
 ****************************************************************************/
-int receive_smb(char *buffer)
+int receive_smb(char *buffer,int timeout)
 {
   int len, msg_type;
   int fd = Client;
+  BOOL ok;
+
   memset(buffer,0,smb_size + 100);
 
  again:
-  if (!read_data(fd,buffer,4))
+
+  if (timeout > 0)
+    ok = (read_with_timeout(fd,buffer,4,4,timeout) == 4);
+  else
+    ok = read_data(fd,buffer,4);
+
+  if (!ok)
     {
-      Debug(0,"couldn't read from client\n");
+      Debug(0,"couldn't read from client (or timeout)\n");
       close_sockets();
       exit(1);
     }
@@ -1510,9 +1532,14 @@ int receive_smb(char *buffer)
     goto again;
   }
 
-  if (!read_data(fd,buffer + 4,len))
+  if (timeout > 0)
+    ok = (read_with_timeout(fd,buffer + 4,len,len,timeout) == len);
+  else
+    ok = read_data(fd,buffer+4,len);
+
+  if (!ok)
     {
-      Debug(0,"couldn't read %d bytes from client. Exiting\n",len);
+      Debug(0,"couldn't read %d bytes from client (or timeout)\n",len);
       close_sockets();
       exit(1);
     }
@@ -1814,7 +1841,7 @@ BOOL send_packet(char *buf,int len,struct in_addr *ip,int port,int type)
     }
 #if 1
   /* allow broadcasts on it */
-  setsockopt(out_fd,SOL_SOCKET,SO_BROADCAST,&one,sizeof(one));
+  setsockopt(out_fd,SOL_SOCKET,SO_BROADCAST,(char *)&one,sizeof(one));
 #endif
 		  
   /* set the address and port */
@@ -2078,7 +2105,7 @@ BOOL name_query(char *inbuf,char *outbuf,char *name,struct in_addr *ip)
   SSVAL(outbuf,8,0);
   SSVAL(outbuf,10,0);  
   p = outbuf+12;
-  name_mangle((unsigned char *)name,(unsigned char *)p);
+  name_mangle(name,p);
   p += name_len(p);
   SSVAL(p,0,0x20);
   SSVAL(p,2,0x1);
@@ -2224,11 +2251,12 @@ struct spwd *getspnam(char *username) /* fake shadow password routine */
 /****************************************************************************
 return the byte checksum of some data
 ****************************************************************************/
-int byte_checksum(unsigned char *buf,int len)
+int byte_checksum(char *buf,int len)
 {
+  unsigned char *p = (unsigned char *)buf;
   int ret = 0;
   while (len--)
-    ret += *buf++;
+    ret += *p++;
   return(ret);
 }
 
@@ -2512,34 +2540,25 @@ char *strdup(char *s)
 #endif
 
 
-int System(const char *command)
+/****************************************************************************
+  Signal handler for SIGPIPE (write on a disconnected socket) 
+****************************************************************************/
+void Abort(void )
 {
-  union wait pstat;
-  pid_t pid;
-  int omask;
-  int intsave, quitsave;
-  
-  if (!command)           /* just checking... */
-    return(1);
-  
-  omask = sigblock(sigmask(SIGCHLD));
-  switch(pid = vfork()) {
-  case -1:                        /* error */
-    (void)sigsetmask(omask);
-    pstat.w_status = 0;
-    pstat.w_retcode = 127;
-    return(pstat.w_status);
-  case 0:                         /* child */
-    (void)sigsetmask(omask);
-    execl("/bin/sh", "sh", "-c", command, (char *)NULL);
-    _exit(127);
-  }
-  intsave = signal(SIGINT, SIG_IGN);
-  quitsave = signal(SIGQUIT, SIG_IGN);
-  pid = waitpid(pid, (int *)&pstat, 0);
-  
-  (void)sigsetmask(omask);
-  (void)signal(SIGINT, intsave);
-  (void)signal(SIGQUIT, quitsave);
-  return(pid == -1 ? -1 : pstat.w_status);
+  Debug(0,"Abort called. Probably got SIGPIPE\n");
+  exit(1);
 }
+
+
+#ifdef REPLACE_STRLEN
+/****************************************************************************
+a replacement strlen() that returns int for solaris
+****************************************************************************/
+int Strlen(char *s)
+{
+  int ret=0;
+  if (!s) return(0);
+  while (*s++) ret++;
+  return(ret);
+}
+#endif
